import functools

import cereal_jar.util

_identity = lambda x:x
class cookiejar:
    load = functools.partial(cereal_jar.util.reader, _identity)
    dump = functools.partial(cereal_jar.util.writer, _identity)



def has_double_percent(text):
    return text.startswith('%%') or '\n%%' in text

def reader(loads, fp):
    chunk = ''
    for line in fp:
        if line.startswith('%%'):
            yield loads(chunk)
            chunk = ''
        else:
            chunk += line

def writer(dumps, obj, fp):
    new = True
    for item in obj:
        if not new:
            fp.write('\n%%\n')
        dumped = dumps(obj)
        if has_double_percent(dumped):
            raise ValueError('The (dumped) object must not contain "\n%%".')
        fp.write(dumped)
        new = False



from distutils.core import setup

from cereal_jar import __version__

setup(name='cereal_jar',
      author='Thomas Levine',
      author_email='_@thomaslevine.com',
      description='Save things in [cookie] jar format',
      url='https://github.com/tlevine/jar',
      packages=['cereal_jar'],
      install_requires = [],
      tests_require = ['nose'],
      version=__version__,
      license='AGPL',
)



import collections
import functools
import email, email.message

import cereal_jar.util

def _dumps(obj):
    m = email.message.Message()
    for k, v in obj.items():
        m[k] = str(v)
    return m.as_string().rstrip('\n')

def _loads(string):
    return collections.OrderedDict(email.message_from_string(string))

class recordjar:
    load = functools.partial(cereal_jar.util.reader, _loads)
    dump = functools.partial(cereal_jar.util.writer, _dumps)
